#!/usr/bin/python3
"""
pyiwd: A graphical frontend for iwd, Intel's iNet Wireless Daemon.
(c) 2021 Johannes Willem Fernhout, BSD 3-Clause License applies.
"""


#from iwdgui import passwd_entry, pyiwd

#$__all__ = ["pyiwd", "passwd_entry"]
#__all__ = ["pyiwd", "passwd_entry"]
